<?php

return [
    'plugins' => [
        'stripe' => [
            'enabled' => true,
            'secretKey' => '',
            'webhookSigningSecret' => '',
            'apiBaseUrl' => 'https://api.stripe.com/v1',
            'stripeVersion' => null,
            'timeout' => 30,
            'webhookTolerance' => 300,
            'debug' => false,
        ],
    ],
];
