<?php

namespace portalpeople\stripe\models;

class Carts extends \backend\models\Cartsbe
{
    public function rules()
    {
        $rules = parent::rules();
        // Add any additional validation rules here if needed
        return $rules;
    }
}
